@@ -3,7 +3,8 @@ from datetime import timedelta
 from datetime import datetime
 from typing import *
 from .hash_utils import *
-from .dynimport import get_abstract_import,call_for_all_tabs
+from .dynimport import get_abstract_import,import_symbols_to_parent,call_for_all_tabs
+
 from .json_utils import (unified_json_loader,
                          find_keys,
                          get_key_values_from_path,
@@ -146,5 +147,5 @@ from .log_utils import get_caller_info,get_logFile,print_or_log,get_json_call_re
 from .error_utils import try_func
 from .class_utils import alias,get_class_inputs,get_set_attr
 from .robust_reader import *
-
+from .robust_readers import ifFunctionsInFiles
 
